@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2017-2019 by Ilya Kotov                                  *
+ *   Copyright (C) 2017-2021 by Ilya Kotov                                  *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,7 +33,7 @@ class FFVideoMetaDataModel : public MetaDataModel
 {
 Q_DECLARE_TR_FUNCTIONS(FFVideoMetaDataModel)
 public:
-    FFVideoMetaDataModel(const QString &path);
+    explicit FFVideoMetaDataModel(const QString &path);
     ~FFVideoMetaDataModel();
     QList<MetaDataItem> extraProperties() const override;
 
