@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2017 by Ilya Kotov                                      *
+ *   Copyright (C) 2017-2021 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,17 +20,15 @@
 
 #include "packetbuffer.h"
 
-PacketBuffer::PacketBuffer(int size)
+PacketBuffer::PacketBuffer(int size) : m_size(size)
 {
-    m_size = size;
-    m_add_index = 0;
-    m_done_index = 0;
-    m_current_count = 0;
     m_packets = new AVPacket*[size];
     for(unsigned int i = 0; i < m_size; ++i)
     {
         m_packets[i] = av_packet_alloc();
+#if (LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58,133,100)) //ffmpeg 4.5
         av_init_packet(m_packets[i]);
+#endif
     }
 }
 
@@ -94,7 +92,9 @@ void PacketBuffer::done()
     if (m_current_count)
     {
         av_packet_unref(m_packets[m_done_index]);
+#if (LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58,133,100)) //ffmpeg 4.5
         av_init_packet(m_packets[m_done_index]);
+#endif
         m_current_count--;
         m_done_index = (m_done_index + 1) % m_size;
     }
@@ -108,7 +108,9 @@ void PacketBuffer::clear()
     for(unsigned int i = 0; i < m_size; ++i)
     {
         av_packet_unref(m_packets[m_done_index]);
+#if (LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58,133,100)) //ffmpeg 4.5
         av_init_packet(m_packets[i]);
+#endif
     }
 }
 
