@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2021 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,7 +33,7 @@ class CueParser;
 class DecoderFFapCUE : public Decoder
 {
 public:
-    DecoderFFapCUE(const QString &url);
+    explicit DecoderFFapCUE(const QString &url);
     virtual ~DecoderFFapCUE();
 
     // Standard Decoder API
