@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2020 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2021 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,7 +18,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QMessageBox>
 #include <taglib/apefile.h>
 #include <taglib/apetag.h>
@@ -69,7 +69,7 @@ QList<TrackInfo *> DecoderFFapFactory::createPlayList(const QString &path, Track
     if(path.contains("://"))
     {
         filePath.remove("ape://");
-        filePath.remove(QRegExp("#\\d+$"));
+        filePath.remove(QRegularExpression("#\\d+$"));
         track = path.section("#", -1).toInt();
         parts = TrackInfo::AllParts; //extract all metadata for single cue track
     }
@@ -116,7 +116,7 @@ QList<TrackInfo *> DecoderFFapFactory::createPlayList(const QString &path, Track
             parser.setProperties(info->properties());
             parser.setUrl("ape", filePath);
             delete info;
-            return (track > 0) ? parser.createPlayList(track) : parser.createPlayList();
+            return parser.createPlayList(track);
         }
 
         info->setValue(Qmmp::ALBUM, TStringToQString(tag->album()));
