@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2021 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,7 +19,7 @@
  ***************************************************************************/
 
 #include <QTextCodec>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <taglib/tag.h>
 #include <taglib/id3v1tag.h>
 #include <taglib/apetag.h>
@@ -28,13 +28,11 @@
 
 FFapMetaDataModel::FFapMetaDataModel(const QString &path, bool readOnly) : MetaDataModel(true)
 {
-    m_stream = nullptr;
-    m_file = nullptr;
     if(path.contains("://"))
     {
         QString p = path;
         p.remove("ape://");
-        p.remove(QRegExp("#\\d+$"));
+        p.remove(QRegularExpression("#\\d+$"));
         m_path = p;
         m_stream = new TagLib::FileStream(QStringToFileName(p), true);
         m_file = new TagLib::APE::File(m_stream);
@@ -80,11 +78,10 @@ QString FFapMetaDataModel::coverPath() const
     return MetaDataManager::instance()->findCoverFile(m_path);
 }
 
-FFapFileTagModel::FFapFileTagModel(TagLib::APE::File *file, TagLib::APE::File::TagTypes tagType)
-        : TagModel()
+FFapFileTagModel::FFapFileTagModel(TagLib::APE::File *file, TagLib::APE::File::TagTypes tagType) : TagModel(),
+    m_file(file),
+    m_tagType(tagType)
 {
-    m_tagType = tagType;
-    m_file = file;
     if (m_tagType == TagLib::APE::File::ID3v1)
     {
         m_tag = m_file->ID3v1Tag();
