@@ -16,7 +16,7 @@
     <message>
         <location filename="../decoderffapfactory.cpp" line="150"/>
         <source>About FFap Audio Plugin</source>
-        <translation>Sobre o suplemento FFap Audio</translation>
+        <translation>Acerca de suplemento FFap Audio</translation>
     </message>
     <message>
         <location filename="../decoderffapfactory.cpp" line="151"/>
@@ -42,12 +42,12 @@
 <context>
     <name>FFapMetaDataModel</name>
     <message>
-        <location filename="../ffapmetadatamodel.cpp" line="67"/>
+        <location filename="../ffapmetadatamodel.cpp" line="65"/>
         <source>Samples</source>
         <translation>Amostras</translation>
     </message>
     <message>
-        <location filename="../ffapmetadatamodel.cpp" line="68"/>
+        <location filename="../ffapmetadatamodel.cpp" line="66"/>
         <source>Version</source>
         <translation>Versão</translation>
     </message>
