@@ -19,7 +19,6 @@
  ***************************************************************************/
 
 #include <QStringList>
-#include <QRegExp>
 #include <QMessageBox>
 #include <xmp.h>
 #include "settingsdialog.h"
@@ -38,19 +37,18 @@ DecoderProperties DecoderXmpFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("XMP Plugin");
-    properties.filters << "*.mod" << "*.m15" << "*.nt" << "*.flx" << "*.wow";
-    properties.filters << "*.dbm" << "*.digi" << "*.emod" << "*.med" << "*.mtn" << "*.okt" << "*.sfx";
-    properties.filters << "*.dtm" << "*.gtk" << "*.mgt";
-    properties.filters << "*.669" << "*.far" << "*.fnk" << "*.imf" << "*.it" << "*.liq" << "*.mdl";
-    properties.filters << "*.mtm" << "*.rtm" << "*.s3m" << "*.stm" << "*.ult" << "*.xm";
-    properties.filters << "*.amf" << "*.gdm" << "*.stx";
-    properties.filters << "*.abk" << "*.amf" << "*.psm" << "*.j2b" << "*.mfp" << "*.smp" << "*.stim" << "*.umx";
-    properties.filters << "*.amd" << "*.rad" << "*.hsc" << "*.s3m";
-    properties.filters << "*.xm";
-    properties.filters << "*.s3z" << "*.s3r" << "*.s3gz";
-    properties.filters << "*.mdz" << "*.mdr" << "*.mdbz" << "*.mdgz";
-    properties.filters << "*.itz" << "*.itr" << "*.itgz";
-    properties.filters << "*.xmr" << "*.xmgz" << "*.xmz";
+    properties.filters = QStringList { "*.mod", "*.m15", "*.nt", "*.flx", "*.wow",
+            "*.dbm", "*.digi", "*.emod", "*.med", "*.mtn", "*.okt", "*.sfx",
+            "*.dtm", "*.gtk", "*.mgt",
+            "*.669", "*.far", "*.fnk", "*.imf", "*.it", "*.liq", "*.mdl",
+            "*.mtm", "*.rtm", "*.s3m", "*.stm", "*.ult", "*.xm",
+            "*.amf", "*.gdm", "*.stx",
+            "*.abk", "*.amf", "*.psm", "*.j2b", "*.mfp", "*.smp", "*.stim", "*.umx",
+            "*.amd", "*.rad", "*.hsc", "*.s3m",
+            "*.xm", "*.s3z", "*.s3r", "*.s3gz",
+            "*.mdz", "*.mdr", "*.mdbz", "*.mdgz",
+            "*.itz", "*.itr", "*.itgz",
+            "*.xmr", "*.xmgz", "*.xmz" };
     properties.description = tr("Module Files");
     //properties.contentType = ;
     properties.shortName = "xmp";
