@@ -4,34 +4,34 @@
 <context>
     <name>DecoderXmpFactory</name>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="40"/>
+        <location filename="../decoderxmpfactory.cpp" line="39"/>
         <source>XMP Plugin</source>
-        <translation>XMP-liitännäinen</translation>
+        <translation>XMP Plugin</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="54"/>
+        <location filename="../decoderxmpfactory.cpp" line="52"/>
         <source>Module Files</source>
-        <translation type="unfinished"></translation>
+        <translation>Moduulitiedostot</translation>
+    </message>
+    <message>
+        <location filename="../decoderxmpfactory.cpp" line="109"/>
+        <source>About XMP Audio Plugin</source>
+        <translation>Tietoja: XMP Audio Plugin</translation>
+    </message>
+    <message>
+        <location filename="../decoderxmpfactory.cpp" line="110"/>
+        <source>Qmmp XMP Audio Plugin</source>
+        <translation>Qmmp XMP Audio Plugin</translation>
     </message>
     <message>
         <location filename="../decoderxmpfactory.cpp" line="111"/>
-        <source>About XMP Audio Plugin</source>
-        <translation type="unfinished"></translation>
+        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
+        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
         <location filename="../decoderxmpfactory.cpp" line="112"/>
-        <source>Qmmp XMP Audio Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decoderxmpfactory.cpp" line="113"/>
-        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>Toteuttanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
-    </message>
-    <message>
-        <location filename="../decoderxmpfactory.cpp" line="114"/>
         <source>Compiled against libxmp-%1</source>
-        <translation type="unfinished"></translation>
+        <translation>Koostettu libxmp-%1</translation>
     </message>
 </context>
 <context>
@@ -39,42 +39,42 @@
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>XMP Plugin Settings</source>
-        <translation>XMP-liitännäisen asetukset</translation>
+        <translation>Asetukset XMP Plugin</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="34"/>
         <source> Amplification factor:</source>
-        <translation type="unfinished"></translation>
+        <translation>Vahvistuskerroin:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="51"/>
         <source>Stereo mixing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Stereomiksaus:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="68"/>
         <source> Interpolation type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Interpolointi tyyppi:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="78"/>
         <source>Lowpass filter effect</source>
-        <translation type="unfinished"></translation>
+        <translation>Lowpass suotimen efekti</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="85"/>
         <source>Use vblank timing</source>
-        <translation type="unfinished"></translation>
+        <translation>Käytä ajoitukseen vblank</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="92"/>
         <source>Emulate Protracker 2.x FX9 bug</source>
-        <translation type="unfinished"></translation>
+        <translation>Jäljittele Protracker 2.x FX9 vikaa</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="99"/>
         <source>Sample rate:</source>
-        <translation>Näytteenottotaajuus:</translation>
+        <translation>Taajuus:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="33"/>
@@ -94,78 +94,78 @@
     <message>
         <location filename="../settingsdialog.cpp" line="36"/>
         <source>Nearest neighbor</source>
-        <translation type="unfinished"></translation>
+        <translation>Lähin naapuri</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="37"/>
         <source>Linear</source>
-        <translation type="unfinished"></translation>
+        <translation>Lineaarinen</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="38"/>
         <source>Cubic spline</source>
-        <translation type="unfinished"></translation>
+        <translation>Kuutio spline</translation>
     </message>
 </context>
 <context>
     <name>XmpMetaDataModel</name>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="53"/>
+        <location filename="../xmpmetadatamodel.cpp" line="52"/>
         <source>Volume scale</source>
-        <translation type="unfinished"></translation>
+        <translation>Voimakkuuden asteikko </translation>
+    </message>
+    <message>
+        <location filename="../xmpmetadatamodel.cpp" line="53"/>
+        <source>Number of patterns</source>
+        <translation>Kuvioiden määrä</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="54"/>
-        <source>Number of patterns</source>
-        <translation type="unfinished"></translation>
+        <source>Number of tracks</source>
+        <translation>Kappaleiden määrä</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="55"/>
-        <source>Number of tracks</source>
-        <translation type="unfinished"></translation>
+        <source>Tracks per pattern</source>
+        <translation>Kappaleita per kuvio</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="56"/>
-        <source>Tracks per pattern</source>
-        <translation type="unfinished"></translation>
+        <source>Number of instruments</source>
+        <translation>Instrumenttien määrä</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="57"/>
-        <source>Number of instruments</source>
-        <translation type="unfinished"></translation>
+        <source>Number of samples</source>
+        <translation>Näytteiden määrä</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="58"/>
-        <source>Number of samples</source>
-        <translation type="unfinished"></translation>
+        <source>Initial speed</source>
+        <translation>Alkunopeus</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="59"/>
-        <source>Initial speed</source>
-        <translation type="unfinished"></translation>
+        <source>Initial BPM</source>
+        <translation>Alkuperäinen BPM</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="60"/>
-        <source>Initial BPM</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../xmpmetadatamodel.cpp" line="61"/>
         <source>Module length in patterns</source>
-        <translation type="unfinished"></translation>
+        <translation>Moduulin kesto kuvioina</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="80"/>
+        <location filename="../xmpmetadatamodel.cpp" line="79"/>
         <source>Samples</source>
-        <translation type="unfinished"></translation>
+        <translation>Samplet</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="88"/>
+        <location filename="../xmpmetadatamodel.cpp" line="87"/>
         <source>Instruments</source>
-        <translation type="unfinished"></translation>
+        <translation>Soittimet</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="93"/>
+        <location filename="../xmpmetadatamodel.cpp" line="92"/>
         <source>Comment</source>
         <translation>Kommentti</translation>
     </message>
