@@ -4,34 +4,34 @@
 <context>
     <name>DecoderXmpFactory</name>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="40"/>
+        <location filename="../decoderxmpfactory.cpp" line="39"/>
         <source>XMP Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>XMP Eklentisi</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="54"/>
+        <location filename="../decoderxmpfactory.cpp" line="52"/>
         <source>Module Files</source>
-        <translation type="unfinished"></translation>
+        <translation>Modül Dosyaları</translation>
+    </message>
+    <message>
+        <location filename="../decoderxmpfactory.cpp" line="109"/>
+        <source>About XMP Audio Plugin</source>
+        <translation>XMP Ses Eklentisi Hakkında</translation>
+    </message>
+    <message>
+        <location filename="../decoderxmpfactory.cpp" line="110"/>
+        <source>Qmmp XMP Audio Plugin</source>
+        <translation>Qmmp XMP Ses Eklentisi</translation>
     </message>
     <message>
         <location filename="../decoderxmpfactory.cpp" line="111"/>
-        <source>About XMP Audio Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decoderxmpfactory.cpp" line="112"/>
-        <source>Qmmp XMP Audio Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decoderxmpfactory.cpp" line="113"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="114"/>
+        <location filename="../decoderxmpfactory.cpp" line="112"/>
         <source>Compiled against libxmp-%1</source>
-        <translation type="unfinished"></translation>
+        <translation>libxmp-%1&apos;e  dayanarak derlendi</translation>
     </message>
 </context>
 <context>
@@ -39,42 +39,42 @@
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>XMP Plugin Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>XMP Eklenti Ayarları</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="34"/>
         <source> Amplification factor:</source>
-        <translation type="unfinished"></translation>
+        <translation>Yükseltme etmeni:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="51"/>
         <source>Stereo mixing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Steryo karıştırma:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="68"/>
         <source> Interpolation type:</source>
-        <translation type="unfinished"></translation>
+        <translation>İnterpolasyon türü:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="78"/>
         <source>Lowpass filter effect</source>
-        <translation type="unfinished"></translation>
+        <translation>Düşük Geçişli filtre etkisi</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="85"/>
         <source>Use vblank timing</source>
-        <translation type="unfinished"></translation>
+        <translation>Vblank zamanlamasını kullan</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="92"/>
         <source>Emulate Protracker 2.x FX9 bug</source>
-        <translation type="unfinished"></translation>
+        <translation>Protracker 2.x FX9 hatasını taklit et</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="99"/>
         <source>Sample rate:</source>
-        <translation type="unfinished"></translation>
+        <translation>Örnekleme oranı:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="33"/>
@@ -94,78 +94,78 @@
     <message>
         <location filename="../settingsdialog.cpp" line="36"/>
         <source>Nearest neighbor</source>
-        <translation type="unfinished"></translation>
+        <translation>Yakınındaki komşu</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="37"/>
         <source>Linear</source>
-        <translation type="unfinished"></translation>
+        <translation>Doğrusal</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="38"/>
         <source>Cubic spline</source>
-        <translation type="unfinished"></translation>
+        <translation>Kübik kama</translation>
     </message>
 </context>
 <context>
     <name>XmpMetaDataModel</name>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="53"/>
+        <location filename="../xmpmetadatamodel.cpp" line="52"/>
         <source>Volume scale</source>
-        <translation type="unfinished"></translation>
+        <translation>Ses ölçeği</translation>
+    </message>
+    <message>
+        <location filename="../xmpmetadatamodel.cpp" line="53"/>
+        <source>Number of patterns</source>
+        <translation>Desenlerin sayısı</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="54"/>
-        <source>Number of patterns</source>
-        <translation type="unfinished"></translation>
+        <source>Number of tracks</source>
+        <translation>Parçaların sayısı</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="55"/>
-        <source>Number of tracks</source>
-        <translation type="unfinished"></translation>
+        <source>Tracks per pattern</source>
+        <translation>Desen başına parçalar</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="56"/>
-        <source>Tracks per pattern</source>
-        <translation type="unfinished"></translation>
+        <source>Number of instruments</source>
+        <translation>Müzik aletlerinin sayısı</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="57"/>
-        <source>Number of instruments</source>
-        <translation type="unfinished"></translation>
+        <source>Number of samples</source>
+        <translation>Örneklerin sayısı</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="58"/>
-        <source>Number of samples</source>
-        <translation type="unfinished"></translation>
+        <source>Initial speed</source>
+        <translation>Başlangıç hızı</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="59"/>
-        <source>Initial speed</source>
-        <translation type="unfinished"></translation>
+        <source>Initial BPM</source>
+        <translation>İlk BPM</translation>
     </message>
     <message>
         <location filename="../xmpmetadatamodel.cpp" line="60"/>
-        <source>Initial BPM</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../xmpmetadatamodel.cpp" line="61"/>
         <source>Module length in patterns</source>
-        <translation type="unfinished"></translation>
+        <translation>Desenlerde modül uzunluğu</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="80"/>
+        <location filename="../xmpmetadatamodel.cpp" line="79"/>
         <source>Samples</source>
-        <translation type="unfinished"></translation>
+        <translation>Örnekler</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="88"/>
+        <location filename="../xmpmetadatamodel.cpp" line="87"/>
         <source>Instruments</source>
-        <translation type="unfinished"></translation>
+        <translation>Müzik aletleri</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="93"/>
+        <location filename="../xmpmetadatamodel.cpp" line="92"/>
         <source>Comment</source>
         <translation>Yorum</translation>
     </message>
