@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2015-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2015-2021 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,7 +29,7 @@ class XmpMetaDataModel : public MetaDataModel
 {
     Q_DECLARE_TR_FUNCTIONS(XmpMetaDataModel)
 public:
-    XmpMetaDataModel(const QString &path);
+    explicit XmpMetaDataModel(const QString &path);
     ~XmpMetaDataModel();
     QList<MetaDataItem> extraProperties() const override;
     QList<MetaDataItem> descriptions() const override;
